==> commons-compiler-2.6.1-sources.jar: org/codehaus/commons/compiler/LocatedException.java <==

/*
 * Janino - An embedded Java[TM] compiler
 *
 * Copyright (c) 2001-2010, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.codehaus.commons.compiler;

/**
 * An {@link Exception} that is associated with an optional {@link Location} in a source file.
 */
public class LocatedException extends CausedException {
    private final Location optionalLocation;

    public LocatedException(String message, Location optionalLocation) {
        super(message);
        this.optionalLocation = optionalLocation;
    }

    public LocatedException(String message, Location optionalLocation, Throwable optionalCause) {
        super(message, optionalCause);
        this.optionalLocation = optionalLocation;
    }

    /**
     * Returns the message specified at creation time, preceeded with nicely formatted location
     * information (if any).
     */
    public String getMessage() {
        return (
            this.optionalLocation == null
            ? super.getMessage()
            : this.optionalLocation.toString() + ": " + super.getMessage()
        );
    }

    /**
     * Returns the {@link Location} object specified at
     * construction time (may be <code>null</code>).
     */
    public Location getLocation() {
        return this.optionalLocation;
    }
}

==> commons-compiler-2.7.8-sources.jar: org/codehaus/commons/compiler/LocatedException.java <==

/*
 * Janino - An embedded Java[TM] compiler
 *
 * Copyright (c) 2001-2010, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.codehaus.commons.compiler;

/** An {@link Exception} that is associated with an optional {@link Location} in a source file. */
public
class LocatedException extends Exception {

    private final Location optionalLocation;

    public
    LocatedException(String message, Location optionalLocation) {
        super(message);
        this.optionalLocation = optionalLocation;
    }

    public
    LocatedException(String message, Location optionalLocation, Throwable optionalCause) {
        super(message, optionalCause);
        this.optionalLocation = optionalLocation;
    }

    /**
     * Returns the message specified at creation time, preceeded with nicely formatted location
     * information (if any).
     */
    @Override public String
    getMessage() {
        return (
            this.optionalLocation == null
            ? super.getMessage()
            : this.optionalLocation.toString() + ": " + super.getMessage()
        );
    }

    /** @return The {@link Location} specified at construction time (may be <code>null</code>) */
    public Location
    getLocation() { return this.optionalLocation; }
}
